==> Bundle-PDF-0.04.tar.gz: Bundle-PDF-0.04/lib/Bundle/PDF.pm <==
package Bundle::PDF;


our $VERSION = '0.04';



1;
__END__;

=head1 NAME

Bundle::PDF - A bundle to install PDF modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::PDF'

=head1 CONTENTS

PDF

Text::Roman

PDF::API2

Compress::Zlib

Getopt::Long

UNIVERSAL::isa

version

Error

Graphics::ColorNames

Image::Size

LWP::Simple

List::Util

PDF::Writer

XML::Twig

XML::Clean

HTML::Tidy

XML::Simple

Number::Format

XML::Parser

PDF::FromHTML

PDF::Report

PDF::ReportWriter

PDF::Create

Test::More

IO::Scalar

PDF::Labels

PDF::Reuse

PDF::Reuse::Tutorial

PDF::Reuse::Barcode

CAM::PDF

Exporter

AutoLoader

Text::PDF

Crypt::RC4

Digest::MD5

File::Temp

IO::All

IPC::Open2

GD

GD::Barcode

Pod::Parser

AppConfig

Parse::RecDescent

Class::MethodMaker

PDF::EasyPDF

PDF::Tk

PDF::Extract

PDF::Table

PDF::API2::Simple

PDF::FDF::Simple

PDF::Xtract

Module::Load

Test::Prereq

Net::FTP

Test::PDF

Business::ReportWriter

XML::Handler::YAWriter

XML::Parser::PerlSAX

PDF::Maki

POSIX

Pod::Pdf

ETL::Pequel

RTF::HTMLConverter

MP3::Info

HTML::TreeBuilder

File::MMagic::XS

File::Extract

Test::Pod

Test::Pod::Coverage

HTML::Parser

HTML::Tagset

HTML::HTMLDoc

Image::ExifTool

URI::Title

URI

Module::Pluggable

File::Type

Pod::HtmlPsPdf

DocSet

DBIx::ReportBuilder

DBIx::SearchBuilder

GD::Graph

Chart::Math::Axis

MIME::Base64

GD::Text

IO::File

Archive::Zip

OpenOffice::OOBuilder

Font::TTF

Algorithm::Diff

Font::TTFMetrics

SWF::File

SWF::Chart

SWF::Search

SWF::Builder

SWF::Header

SWF::NeedsRecompile

FLV::Info

File::Headerinfo::SWF

File::Binary

IO::Handle

IO::File

Font::AFM

Sys::Hostname

Text::CSV_XS

PostScript::Document

PostScript::MailLabels

PostScript::CDCover

PostScript::File

PostScript::Graph

PostScript::Columns

PostScript::EPSF

PostScript::Font

PostScript::Simple

PostScript::Simple::Table

RPC::JSON

MP3::Info

File::Spec

Exporter::Lite

Class::Accessor

Text::FIGlet

Text::Typography

Text::Iconv

Image::ANSI

Tk

Tk::Font::Dialog

ExtUtils::Manifest

Math::Bezier::Convert

AMF::Perl

Bundle::PerlPoint

SVG

GD::SVG

SVG::Graph

SVG::TT::Graph

PTools::SDF

Pod::Sdf

Pod::PerlPoint

FrameMaker::FromHTML

XML::ApacheFOP

App::a2pdf

Image::Magick::Thumbnail

Image::Magick::Thumbnail::PDF

Image::Magick::Thumbnail::Fixed

Bundle::Unicode


=head2 DESCRIPTION

PDF::CreateSimple was left out because of compilation problems. 
PDF::Template was left out because it requires the third-party
PDFLib-Lite.


=head1 SEE ALSO

For PDFLib-Lite. see www.pdflib.com

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-PDF-0.05.tar.gz: Bundle-PDF-0.05/lib/Bundle/PDF.pm <==
package Bundle::PDF;


our $VERSION = '0.05';



1;
__END__;

=head1 NAME

Bundle::PDF - A bundle to install PDF modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::PDF'

=head1 CONTENTS

PDF

Text::Roman

PDF::API2

Compress::Zlib

Getopt::Long

UNIVERSAL::isa

version

Error

Graphics::ColorNames

Image::Size

LWP::Simple

List::Util

PDF::Writer

XML::Twig

XML::Clean

HTML::Tidy

XML::Simple

Number::Format

XML::Parser

PDF::FromHTML

PDF::Report

PDF::ReportWriter

PDF::Create

Test::More

IO::Scalar

PDF::Labels

PDF::Reuse

PDF::Reuse::Tutorial

PDF::Reuse::Barcode

CAM::PDF

Exporter

AutoLoader

Text::PDF

Crypt::RC4

Digest::MD5

File::Temp

IO::All

IPC::Open2

GD

GD::Barcode

Pod::Parser

AppConfig

Parse::RecDescent

Class::MethodMaker

PDF::EasyPDF

PDF::Tk

PDF::Extract

PDF::Table

PDF::API2::Simple

PDF::FDF::Simple

PDF::Xtract

Module::Load

Test::Prereq

Net::FTP

Test::PDF

Business::ReportWriter

XML::Handler::YAWriter

XML::Parser::PerlSAX

PDF::Maki

POSIX

Pod::Pdf

ETL::Pequel

RTF::HTMLConverter

MP3::Info

HTML::TreeBuilder

File::MMagic::XS

File::Extract

Test::Pod

Test::Pod::Coverage

HTML::Parser

HTML::Tagset

HTML::HTMLDoc

Image::ExifTool

URI::Title

URI

Module::Pluggable

File::Type

Pod::HtmlPsPdf

DocSet

DBIx::ReportBuilder

DBIx::SearchBuilder

GD::Graph

Chart::Math::Axis

MIME::Base64

GD::Text

IO::File

Archive::Zip

OpenOffice::OOBuilder

Font::TTF

Algorithm::Diff

Font::TTFMetrics

SWF::File

SWF::Chart

SWF::Search

SWF::Builder

SWF::Header

SWF::NeedsRecompile

FLV::Info

File::Headerinfo::SWF

File::Binary

IO::Handle

IO::File

Font::AFM

Sys::Hostname

Text::CSV_XS

PostScript::Document

PostScript::MailLabels

PostScript::CDCover

PostScript::File

PostScript::Graph

PostScript::Columns

PostScript::EPSF

PostScript::Font

PostScript::Simple

PostScript::Simple::Table

RPC::JSON

MP3::Info

File::Spec

Exporter::Lite

Class::Accessor

Text::FIGlet

Text::Typography

Text::Iconv

Image::ANSI

Tk

Tk::Font::Dialog

ExtUtils::Manifest

Math::Bezier::Convert

AMF::Perl

Bundle::PerlPoint

SVG

GD::SVG

SVG::Graph

SVG::TT::Graph

PTools::SDF

Pod::Sdf

Pod::PerlPoint

FrameMaker::FromHTML

XML::ApacheFOP

App::a2pdf

Image::Magick::Thumbnail

Image::Magick::Thumbnail::PDF

Image::Magick::Thumbnail::Fixed

Date::Simple

Data::Grove

XML::RegExp

XML::Parser

LWP::UserAgent

XML::DOM

XML::Xpath

Test::XML

Algorithm::Points::MinimumDistance

Class::MethodMaker

Scalar::Util

UML::Sequence

Ernno

XML::SAX::Base

Geo::ShapeFile

XML::Generator

Transform::Canvas

Bundle::Unicode

XSLoader

overload

Data::Dumper

HTML::Entities

SVG::Parser

SVG::DOM

SVG::XML

SVG::Element

SVG::Metadata

HTML::Entities::Numbered

SVG::DOM2

SVG::DOM2::Element::Document

Image::Info::SVG

XML::Generator::SVG::ShapeFile

SVG::Template::Graph

SVG::GD

SVG::SVG2zinc

SVG::Plot

Graph::Easy

Graph::Easy::As_svg

SVGGraph::Pie

=head2 DESCRIPTION

PDF::CreateSimple was left out because of compilation problems. 
PDF::Template was left out because it requires the third-party
PDFLib-Lite.

=head1 SEE ALSO

For PDFLib-Lite. see www.pdflib.com

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
